@@ -26,7 +26,10 @@ import logging
 import os
 import re
 from bottle import Bottle
-from .markdown import to_html as markdown_to_html
+try:
+    from .markdown import to_html as markdown_to_html
+except ImportError:
+    mdmod_is_not_installed = True
 from .rst import to_html as rst_to_html
 from .server import StoppableCherryPyServer
 
@@ -46,11 +49,11 @@ bottle.TEMPLATE_PATH = [DEFAULT_TEMPLATE_DIR, './']
 DEFAULT_STATIC_FILES_DIR = os.path.normpath(os.path.join(__path__, 'static'))
 
 
-def build_app(filename, port, debug, quiet):
+def build_app(filename, port, debug, quiet, filetype):
     app = Bottle()
     server = StoppableCherryPyServer(port=port, debug=debug, quiet=quiet)
     root, ext = os.path.splitext(filename)
-    markup = Markup(filename)
+    markup = Markup(filename, filetype)
     dirname, basename = os.path.split(markup.filename)
     title = '%s - %s' % (basename, dirname)
 
@@ -83,7 +86,7 @@ def build_app(filename, port, debug, quiet):
             logging.critical('%s: %s', markup.filename, e.strerror)
             raise e
 
-        if file_timestamp == timestamp: # Keep old entry
+        if file_timestamp == timestamp:     # Keep old entry
             return {
                 'title': title,
                 'timestamp': file_timestamp,
@@ -109,6 +112,7 @@ def build_app(filename, port, debug, quiet):
 
     return run_app
 
+
 class Markup(object):
     _markup_detect = {}
     _markup_render = {}
@@ -119,15 +123,17 @@ class Markup(object):
         cls._markup_detect[markup] = ftdetect
         cls._markup_render[markup] = render_func
 
-    def __init__(self, filename):
+    def __init__(self, filename, filetype=None):
         filename = os.path.abspath(os.path.expanduser(filename))
-        if os.path.exists(filename) and os.path.isfile(filename):
-            self._filename = filename
-            self._basename = os.path.basename(filename)
-            self._dirname = os.path.dirname(filename)
-            self._filetype = self._ftdetect(filename)
-        else:
+        if not os.path.exists(filename) or not os.path.isfile(filename):
             raise ValueError('invalid filename')
+        self._filename = filename
+        self._basename = os.path.basename(filename)
+        self._dirname = os.path.dirname(filename)
+        _filename = filename
+        if filetype:
+            _filename = "dummy.%s" % filetype
+        self._filetype = self._ftdetect(_filename)
 
     def _ftdetect(self, filename):
         # Markup._markup_detect
@@ -160,15 +166,18 @@ class Markup(object):
         return locals()
     html = property(**html())
 
-Markup.add_markup('markdown', r'\.(markdown|md|mdown|mkd|mkdn)$', markdown_to_html)
+if 'mdmod_is_not_installed' not in locals():
+    Markup.add_markup('markdown', r'\.(markdown|md|mdown|mkd|mkdn)$', markdown_to_html)
 Markup.add_markup('rst', r'\.(rst|rest)$', rst_to_html)
 
 
-def quickstart(markdown_file, port, debug=False, quiet=True):
-    app = build_app(filename=markdown_file, port=port, debug=debug, quiet=quiet)
+def quickstart(markdown_file, port, debug=False, quiet=True, filetype=None):
+    app = build_app(filename=markdown_file, port=port,
+                    debug=debug, quiet=quiet, filetype=filetype)
     logging.debug('starting server at port %d', port)
     app()
 
+
 def export_html(markdown_file, export_file):
     markup = Markup(markdown_file)
     dirname, basename = os.path.split(markup.filename)
